@@ -18,7 +18,8 @@ fn navigation_benchmark(c: &mut Criterion) {
     });
 
     let lua = mlua::Lua::new();
-    let mut app = app::App::create(PWD.into(), &lua, None).expect("failed to create app");
+    let mut app =
+        app::App::create(PWD.into(), &lua, None, [].into()).expect("failed to create app");
 
     app = app
         .clone()
@@ -96,7 +97,8 @@ fn draw_benchmark(c: &mut Criterion) {
     });
 
     let lua = mlua::Lua::new();
-    let mut app = app::App::create(PWD.into(), &lua, None).expect("failed to create app");
+    let mut app =
+        app::App::create(PWD.into(), &lua, None, [].into()).expect("failed to create app");
 
     app = app
         .clone()
