@@ -1545,14 +1545,26 @@ impl App {
         let mut config = lua::init(lua)?;
 
         let config_file = if let Some(path) = config_file {
-            path
+            Some(path)
         } else if let Some(dir) = dirs::home_dir() {
-            dir.join(".config").join("xplr").join("init.lua")
+            let path = dir.join(".config").join("xplr").join("init.lua");
+            if path.exists() {
+                Some(path)
+            } else {
+                None
+            }
         } else {
-            PathBuf::from("/").join("etc").join("xplr").join("init.lua")
+            let path = PathBuf::from("/").join("etc").join("xplr").join("init.lua");
+            if path.exists() {
+                Some(path)
+            } else {
+                None
+            }
         };
 
-        let config_files = std::iter::once(config_file).chain(extra_config_files.into_iter());
+        let config_files = config_file
+            .into_iter()
+            .chain(extra_config_files.into_iter());
 
         let mut load_errs = vec![];
         for config_file in config_files {
@@ -1593,7 +1605,7 @@ impl App {
         };
 
         let pid = std::process::id();
-        let session_path = dirs::runtime_dir()
+        let mut session_path = dirs::runtime_dir()
             .unwrap_or_else(env::temp_dir)
             .join("xplr")
             .join("session")
@@ -1601,6 +1613,16 @@ impl App {
             .to_string_lossy()
             .to_string();
 
+        if fs::create_dir_all(&session_path).is_err() {
+            session_path = env::temp_dir()
+                .join("xplr")
+                .join("session")
+                .join(&pid.to_string())
+                .to_string_lossy()
+                .to_string();
+            fs::create_dir_all(&session_path)?;
+        }
+
         let mut explorer_config = ExplorerConfig::default();
         if !config.general().show_hidden() {
             explorer_config.filters.replace(NodeFilterApplicable::new(
@@ -1637,8 +1659,6 @@ impl App {
             last_modes: Default::default(),
         };
 
-        fs::create_dir_all(app.session_path())?;
-
         for err in load_errs {
             app = app.log_error(err)?
         }
