@@ -18,15 +18,21 @@ use std::io::Write;
 use std::path::PathBuf;
 use std::process::{Command, ExitStatus, Stdio};
 use std::sync::mpsc;
-use termion::get_tty;
 use tui::backend::CrosstermBackend;
 use tui::Terminal;
 
+pub fn get_tty() -> io::Result<fs::File> {
+    fs::OpenOptions::new()
+        .read(true)
+        .write(true)
+        .open("/dev/tty")
+}
+
 fn call_lua(
     app: &app::App,
     lua: &mlua::Lua,
     func: &str,
-    silent: bool,
+    _silent: bool,
 ) -> Result<Option<Vec<app::ExternalMsg>>> {
     let _focus_index = app
         .directory_buffer()
@@ -34,12 +40,6 @@ fn call_lua(
         .unwrap_or_default()
         .to_string();
 
-    let (_, _, _) = if silent {
-        (Stdio::null(), Stdio::null(), Stdio::null())
-    } else {
-        (get_tty()?.into(), get_tty()?.into(), get_tty()?.into())
-    };
-
     let arg = app.to_lua_arg();
     let arg = lua.to_value(&arg)?;
     lua::call(lua, func, arg)
@@ -99,7 +99,8 @@ fn start_fifo(path: &str, focus_path: &str) -> Result<fs::File> {
 pub struct Runner {
     pwd: PathBuf,
     focused_path: Option<PathBuf>,
-    config: Option<PathBuf>,
+    config_file: Option<PathBuf>,
+    extra_config_files: Vec<PathBuf>,
     on_load: Vec<app::ExternalMsg>,
     read_only: bool,
 }
@@ -120,7 +121,8 @@ impl Runner {
         Ok(Self {
             pwd,
             focused_path,
-            config: None,
+            config_file: Default::default(),
+            extra_config_files: Default::default(),
             on_load: Default::default(),
             read_only: Default::default(),
         })
@@ -131,8 +133,13 @@ impl Runner {
         self
     }
 
-    pub fn with_config(mut self, config: Option<PathBuf>) -> Self {
-        self.config = config;
+    pub fn with_config(mut self, config_file: Option<PathBuf>) -> Self {
+        self.config_file = config_file;
+        self
+    }
+
+    pub fn with_extra_config(mut self, config_files: Vec<PathBuf>) -> Self {
+        self.extra_config_files = config_files;
         self
     }
 
@@ -142,8 +149,9 @@ impl Runner {
     }
 
     pub fn run(self) -> Result<Option<String>> {
-        let lua = mlua::Lua::new();
-        let mut app = app::App::create(self.pwd, &lua, self.config)?;
+        // Why unsafe? See https://github.com/sayanarijit/xplr/issues/309
+        let lua = unsafe { mlua::Lua::unsafe_new() };
+        let mut app = app::App::create(self.pwd, &lua, self.config_file, self.extra_config_files)?;
         app.config.general.set_read_only(self.read_only);
 
         fs::create_dir_all(app.session_path())?;
@@ -185,7 +193,7 @@ impl Runner {
         execute!(stdout, term::EnterAlternateScreen)?;
 
         let mut fifo: Option<fs::File> = if let Some(path) = app.config().general().start_fifo() {
-            match start_fifo(&path, &app.focused_node_str()) {
+            match start_fifo(path, &app.focused_node_str()) {
                 Ok(file) => Some(file),
                 Err(e) => {
                     app = app.log_error(e.to_string())?;
